You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2020/08/18 22:47:16 UTC

[openoffice] branch AOO42X updated: Fixed typos (shure -> sure)

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new d0dd86958 Fixed typos (shure -> sure)
d0dd86958 is described below

commit d0dd869587a99dfd0dcf95dfafb73a7d5e36f956
Author: mseidel <ms...@apache.org>
AuthorDate: Wed Aug 19 00:39:18 2020 +0200

    Fixed typos (shure -> sure)
    
    (cherry picked from commit 01ad09a0c915d261b7260c626c3424e027e76f95)
---
 main/dbaccess/source/core/api/RowSetCache.cxx                |  2 +-
 main/filter/source/config/cache/cacheitem.hxx                |  2 +-
 main/filter/source/config/cache/filtercache.hxx              |  2 +-
 main/filter/source/config/cache/typedetection.cxx            | 12 ++++++------
 main/framework/inc/helper/statusindicatorfactory.hxx         |  2 +-
 main/framework/inc/properties.h                              |  2 +-
 .../qa/complex/framework/recovery/RecoveryTest.java          |  4 ++--
 .../qa/complex/framework/recovery/RecoveryTools.java         |  2 +-
 main/framework/source/dispatch/dispatchprovider.cxx          |  4 ++--
 main/framework/source/fwi/jobs/configaccess.cxx              |  4 ++--
 main/framework/source/inc/loadenv/actionlockguard.hxx        |  4 ++--
 main/framework/source/jobs/job.cxx                           |  2 +-
 main/framework/source/loadenv/loadenv.cxx                    |  6 +++---
 main/framework/source/services/frame.cxx                     |  2 +-
 main/io/source/acceptor/acc_socket.cxx                       |  2 +-
 .../OfficeDev/DesktopEnvironment/DocumentView.java           |  2 +-
 main/offapi/com/sun/star/task/XJob.idl                       |  2 +-
 .../tests/basic/ifc/sdbc/XResultSet/sdbc_XResultSet.xba      |  2 +-
 main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java  |  2 +-
 main/sal/osl/os2/socket.c                                    |  2 +-
 main/sal/osl/unx/socket.c                                    |  2 +-
 main/svl/source/items/style.cxx                              |  2 +-
 main/svtools/source/filter/filter2.cxx                       |  2 +-
 main/unotools/source/config/configitem.cxx                   |  2 +-
 24 files changed, 35 insertions(+), 35 deletions(-)

diff --git a/main/dbaccess/source/core/api/RowSetCache.cxx b/main/dbaccess/source/core/api/RowSetCache.cxx
index 654ad17..20dbf59 100644
--- a/main/dbaccess/source/core/api/RowSetCache.cxx
+++ b/main/dbaccess/source/core/api/RowSetCache.cxx
@@ -987,7 +987,7 @@ sal_Bool ORowSetCache::moveWindow()
 			sal_Bool bCheck = m_pCacheSet->absolute(nPos);
 			bCheck = fill(aIter,aEnd,nPos,bCheck); // refill the region wew don't need anymore
 
-			// we have to read one row forward to enshure that we know when we are on last row
+			// we have to read one row forward to ensure that we know when we are on last row
 			// but only when we don't know it already
 			sal_Bool bOk = sal_True;
 			if(bCheck && !m_bRowCountFinal)
diff --git a/main/filter/source/config/cache/cacheitem.hxx b/main/filter/source/config/cache/cacheitem.hxx
index dac8dc8..99a055c 100644
--- a/main/filter/source/config/cache/cacheitem.hxx
+++ b/main/filter/source/config/cache/cacheitem.hxx
@@ -153,7 +153,7 @@ class CacheItem : public ::comphelper::SequenceAsHashMap
 
         /** @short  because we know two UIName properties
                     (a list with all locales and the value
-                    for the current locale only), we must be shure
+                    for the current locale only), we must be sure
                     that the correspond together.
 
             @param  sActLocale
diff --git a/main/filter/source/config/cache/filtercache.hxx b/main/filter/source/config/cache/filtercache.hxx
index 8e05b6d..f14fc5e 100644
--- a/main/filter/source/config/cache/filtercache.hxx
+++ b/main/filter/source/config/cache/filtercache.hxx
@@ -882,7 +882,7 @@ class FilterCache : public BaseLock
         /** @short  try to load the requested item on demand from the underlying configuration
                     layer.
 
-            @descr  The outside code has to be shure, that the item does not already exists
+            @descr  The outside code has to be sure, that the item does not already exists
                     inside this cachse. Otherwise it will be loaded twice. This method
                     doesn't check such constellations!
 
diff --git a/main/filter/source/config/cache/typedetection.cxx b/main/filter/source/config/cache/typedetection.cxx
index bbadb25..a2847aa 100644
--- a/main/filter/source/config/cache/typedetection.cxx
+++ b/main/filter/source/config/cache/typedetection.cxx
@@ -278,7 +278,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
             // SAFE ->
             ::osl::ResettableMutexGuard aLock(m_aLock);
 
-            // Attention: For executing next lines of code, We must be shure that
+            // Attention: For executing next lines of code, We must be sure that
             // all filters already loaded :-(
             // That can disturb our "load on demand feature". But we have no other chance!
             m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
@@ -359,7 +359,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
         // SAFE ->
         ::osl::ResettableMutexGuard aLock(m_aLock);
 
-        // Attention: For executing next lines of code, We must be shure that
+        // Attention: For executing next lines of code, We must be sure that
         // all filters already loaded :-(
         // That can disturb our "load on demand feature". But we have no other chance!
         m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
@@ -616,7 +616,7 @@ sal_Bool TypeDetection::impl_getPreselectionForDocumentService(const ::rtl::OUSt
         // SAFE -> --------------------------
         ::osl::ResettableMutexGuard aLock(m_aLock);
 
-        // Attention: For executing next lines of code, We must be shure that
+        // Attention: For executing next lines of code, We must be sure that
         // all filters already loaded :-(
         // That can disturb our "load on demand feature". But we have no other chance!
         m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
@@ -687,7 +687,7 @@ void TypeDetection::impl_getPreselection(const css::util::URL&                aP
                                                ::comphelper::MediaDescriptor& rDescriptor,
                                                FlatDetection&                 rFlatTypes )
 {
-    // done to be shure, that only valid results leave this function!
+    // done to be sure, that only valid results leave this function!
     rFlatTypes.clear();
 
     /* #i55122#
@@ -1086,7 +1086,7 @@ void TypeDetection::impl_seekStreamToZero(comphelper::MediaDescriptor& rDescript
 
     // Dont distrub the user for "non existing files - means empty URLs" or
     // if we was forced to detect a stream.
-    // Reason behind: We must be shure to ask user for "unknown contents" only ...
+    // Reason behind: We must be sure to ask user for "unknown contents" only ...
     // and not for "missing files". Especially if detection is done by a stream only
     // we can't check if the stream points to an "existing content"!
     if (
@@ -1109,7 +1109,7 @@ void TypeDetection::impl_seekStreamToZero(comphelper::MediaDescriptor& rDescript
         // "OK" pressed => verify the selected filter, get it's coressponding
         // type and return it. (BTW: We must update the media descriptor here ...)
         // The user selected explicitly a filter ... but normally we are interested on
-        // a type here only. But we must be shure, that the selected filter is used
+        // a type here only. But we must be sure, that the selected filter is used
         // too and no ambigous filter registration disturb us .-)
         
         ::rtl::OUString sFilter = aRequest.getFilter();
diff --git a/main/framework/inc/helper/statusindicatorfactory.hxx b/main/framework/inc/helper/statusindicatorfactory.hxx
index be784a5..fdeba21 100644
--- a/main/framework/inc/helper/statusindicatorfactory.hxx
+++ b/main/framework/inc/helper/statusindicatorfactory.hxx
@@ -322,7 +322,7 @@ class StatusIndicatorFactory : public  css::lang::XTypeProvider
 
         /** @short  try to "share the current thread in an intelligent manner" :-)
 
-            @param  Overwrites our algorithm for Reschedule and force it to be shure
+            @param  Overwrites our algorithm for Reschedule and force it to be sure
                     that our progress was painted right.
          */
         void impl_reschedule(sal_Bool bForceUpdate);
diff --git a/main/framework/inc/properties.h b/main/framework/inc/properties.h
index 0e97062..25ed10a 100644
--- a/main/framework/inc/properties.h
+++ b/main/framework/inc/properties.h
@@ -314,7 +314,7 @@ class PropHelper
     {
         sal_Bool bChanged = sal_False;
 
-        // clear return parameter to be shure, to put out only valid values ...
+        // clear return parameter to be sure, to put out only valid values ...
         aOldValue.clear();
         aChangedValue.clear();
 
diff --git a/main/framework/qa/complex/framework/recovery/RecoveryTools.java b/main/framework/qa/complex/framework/recovery/RecoveryTools.java
index 8c7f8f4..b57907a 100644
--- a/main/framework/qa/complex/framework/recovery/RecoveryTools.java
+++ b/main/framework/qa/complex/framework/recovery/RecoveryTools.java
@@ -251,7 +251,7 @@ public class RecoveryTools {
             multi ++;
         }
 
-        // be shure that office is closed
+        // be sure that office is closed
         if (ph != null) ph.kill();
     }
     
diff --git a/main/framework/source/dispatch/dispatchprovider.cxx b/main/framework/source/dispatch/dispatchprovider.cxx
index bc15127..148dd58 100644
--- a/main/framework/source/dispatch/dispatchprovider.cxx
+++ b/main/framework/source/dispatch/dispatchprovider.cxx
@@ -772,8 +772,8 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_getOrCreat
 /**
     @short      check URL for support by our used loader or handler
     @descr      If we must return our own dispatch helper implementations (self, blank, create dispatcher!)
-                we should be shure, that URL describe any loadable content. Otherwise slot/uno URLs
-                will be detected ... but there exist nothing for ral loading into a target frame!
+                we should be sure, that URL describe any loadable content. Otherwise slot/uno URLs
+                will be detected ... but there exist nothing for real loading into a target frame!
 
     @param      aURL
                     URL which should be "detected"
diff --git a/main/framework/source/fwi/jobs/configaccess.cxx b/main/framework/source/fwi/jobs/configaccess.cxx
index c905a00..fa844c3 100644
--- a/main/framework/source/fwi/jobs/configaccess.cxx
+++ b/main/framework/source/fwi/jobs/configaccess.cxx
@@ -127,7 +127,7 @@ ConfigAccess::EOpenMode ConfigAccess::getMode() const
 void ConfigAccess::open( /*IN*/ EOpenMode eMode )
 {
     /* SAFE { */
-    // We must lock the whole method to be shure, that nobody
+    // We must lock the whole method to be sure, that nobody
     // outside uses our internal member m_xAccess!
     WriteGuard aWriteLock(m_aLock);
 
@@ -190,7 +190,7 @@ void ConfigAccess::open( /*IN*/ EOpenMode eMode )
 void ConfigAccess::close()
 {
     /* SAFE { */
-    // Lock the whole method, to be shure that nobody else uses our internal members
+    // Lock the whole method, to be sure that nobody else uses our internal members
     // during this time.
     WriteGuard aWriteLock(m_aLock);
 
diff --git a/main/framework/source/jobs/job.cxx b/main/framework/source/jobs/job.cxx
index 814f5ca..6c114a9 100644
--- a/main/framework/source/jobs/job.cxx
+++ b/main/framework/source/jobs/job.cxx
@@ -552,7 +552,7 @@ void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
             connection.
 
             Further we are listener for closing of the (possible valid)
-            given frame. We must be shure, that this ressource won't be gone
+            given frame. We must be sure, that this ressource won't be gone
             if our internal job is still running.
 */
 void Job::impl_startListening()
diff --git a/main/framework/source/loadenv/loadenv.cxx b/main/framework/source/loadenv/loadenv.cxx
index 5cf7bfb..a516b1a 100644
--- a/main/framework/source/loadenv/loadenv.cxx
+++ b/main/framework/source/loadenv/loadenv.cxx
@@ -677,7 +677,7 @@ LoadEnv::EContentType LoadEnv::classifyContent(const ::rtl::OUString&
     //     Note: These URL schemata are fix and well known ...
     //     But there can be some additional ones, which was not
     //     defined at implementation time of this class :-(
-    //     So we have to make shure, that the following code
+    //     So we have to make sure, that the following code
     //     can detect such protocol schemata too :-)
 
     if(
@@ -1451,7 +1451,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchAlreadyLoaded()
 
     if (xResult.is())
     {
-        // Now we are shure, that this task includes the searched document.
+        // Now we are sure, that this task includes the searched document.
         // It's time to activate it. As special feature we try to jump internaly
         // if an optional jumpmark is given too.
         if (m_aURL.Mark.getLength())
@@ -1673,7 +1673,7 @@ void LoadEnv::impl_reactForLoadingState()
 		// Try to reactivate the old document (if any exists!)
 		css::uno::Reference< css::frame::XController > xOldDoc = m_xTargetFrame->getController();
 		// clear does not depend from reactivation state of a might existing old document!
-		// We must make shure, that a might following getTargetComponent() call does not return
+		// We must make sure, that a might following getTargetComponent() call does not return
 		// the old document!
 		m_xTargetFrame.clear();
 		if (xOldDoc.is())
diff --git a/main/framework/source/services/frame.cxx b/main/framework/source/services/frame.cxx
index 3896531..a35e93e 100644
--- a/main/framework/source/services/frame.cxx
+++ b/main/framework/source/services/frame.cxx
@@ -2396,7 +2396,7 @@ void SAL_CALL Frame::windowClosing( const css::lang::EventObject& ) throw( css::
                              But frames without a parent are top too. So it's not possible to check isTop() here!
                              We have to look for the type of our parent.
                            - if we are a task frame, then we have to check if we are the first one.
-                             We use a static variable to do so. They will be reset to afterwards be shure
+                             We use a static variable to do so. They will be reset to afterwards be sure
                              that further calls of this method doesn't do anything then.
                            - Then we have to trigger the right event string on the global job executor.
 
diff --git a/main/io/source/acceptor/acc_socket.cxx b/main/io/source/acceptor/acc_socket.cxx
index 2c07d48..478b16e 100644
--- a/main/io/source/acceptor/acc_socket.cxx
+++ b/main/io/source/acceptor/acc_socket.cxx
@@ -293,7 +293,7 @@ namespace io_acceptor {
 			throw(::com::sun::star::io::IOException,
 				  ::com::sun::star::uno::RuntimeException)
 	{
-		// enshure close is called only once
+		// ensure close is called only once
 		if(  1 == osl_incrementInterlockedCount( (&m_nStatus) ) )
 		{
 			m_socket.shutdown();
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
index c76522b..247ee06 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
@@ -205,7 +205,7 @@ public class DocumentView extends    JFrame
         if(ViewContainer.mbInplace==true)
         {
             // inplace document view can't be initialized without a visible parent window hierarchy!
-            // So make shure that we are visible in every case!
+            // So make sure that we are visible in every case!
             this.setVisible(true);
             mxFrame = FunctionHelper.createViewFrame(msName,maDocumentView);
         }
diff --git a/main/offapi/com/sun/star/task/XJob.idl b/main/offapi/com/sun/star/task/XJob.idl
index 60ec93b..77e8033 100644
--- a/main/offapi/com/sun/star/task/XJob.idl
+++ b/main/offapi/com/sun/star/task/XJob.idl
@@ -45,7 +45,7 @@ module com {  module sun {  module star {  module task {
 
     <p>
     Instead of <type>XAsyncJob</type> the implementation of this interface
-    will be executed synchronously everytimes. That means: they can be shure that the
+    will be executed synchronously everytimes. That means: they can be sure that the
     current stack context will be blocked till this job finish it's work.
     </p>
 
diff --git a/main/qadevOOo/tests/basic/ifc/sdbc/XResultSet/sdbc_XResultSet.xba b/main/qadevOOo/tests/basic/ifc/sdbc/XResultSet/sdbc_XResultSet.xba
index 38e34ed..7901f92 100644
--- a/main/qadevOOo/tests/basic/ifc/sdbc/XResultSet/sdbc_XResultSet.xba
+++ b/main/qadevOOo/tests/basic/ifc/sdbc/XResultSet/sdbc_XResultSet.xba
@@ -54,7 +54,7 @@ On Error Goto ErrHndl
     Dim bOK As Boolean
 
 
-    Out.Log("ReCreating Object, to be shure that it is in initial state.")
+    Out.Log("ReCreating Object, to be sure that it is in initial state.")
 
     Test.StartMethod("beforeFirst()")
     Test.StartMethod("isBeforeFirst()")
diff --git a/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java b/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java
index 2e59afb..47adb52 100644
--- a/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java
+++ b/main/qadevOOo/tests/java/ifc/xml/sax/_XDocumentHandler.java
@@ -162,7 +162,7 @@ public class _XDocumentHandler extends MultiMethodTest {
 
         }else{
             log.println("object realtion 'XDocumentHandler.TargetDocumentSetter' not used.");
-            log.println("be shure that the test have a target to write throu");
+            log.println("be sure that the test have a target to write through");
         }
     }
 
diff --git a/main/sal/osl/os2/socket.c b/main/sal/osl/os2/socket.c
index 194cead..c87df62 100644
--- a/main/sal/osl/os2/socket.c
+++ b/main/sal/osl/os2/socket.c
@@ -2890,7 +2890,7 @@ void SAL_CALL osl_getLastSocketErrorDescription(oslSocket Socket, rtl_uString **
 
 void SAL_CALL osl_psz_getLastSocketErrorDescription(oslSocket pSocket, sal_Char* pBuffer, sal_uInt32 BufferSize)
 {
-	/* make shure pBuffer will be a zero-terminated string even when strncpy has to cut */
+	/* make sure pBuffer will be a zero-terminated string even when strncpy has to cut */
 	pBuffer[BufferSize-1]= '\0';
 
     if ( pSocket == 0 )
diff --git a/main/sal/osl/unx/socket.c b/main/sal/osl/unx/socket.c
index a8f7bca..1ab2cb5 100644
--- a/main/sal/osl/unx/socket.c
+++ b/main/sal/osl/unx/socket.c
@@ -2860,7 +2860,7 @@ void SAL_CALL osl_getLastSocketErrorDescription(oslSocket Socket, rtl_uString **
 
 void SAL_CALL osl_psz_getLastSocketErrorDescription(oslSocket pSocket, sal_Char* pBuffer, sal_uInt32 BufferSize)
 {
-	/* make shure pBuffer will be a zero-terminated string even when strncpy has to cut */
+	/* make sure pBuffer will be a zero-terminated string even when strncpy has to cut */
 	pBuffer[BufferSize-1]= '\0';
 
     if ( pSocket == 0 )
diff --git a/main/svl/source/items/style.cxx b/main/svl/source/items/style.cxx
index 9d3aa5f..9bce1fc 100644
--- a/main/svl/source/items/style.cxx
+++ b/main/svl/source/items/style.cxx
@@ -1123,7 +1123,7 @@ sal_Bool SfxStyleSheetBasePool::Store( SvStream& rStream, sal_Bool bUsed )
 	// die StyleSheets in einen MultiVarRecord
 	{
 		// Bug 79478:
-		// make a check loop, to be shure, that the converted names are also
+		// make a check loop, to be sure, that the converted names are also
 		// unique like the originals! In other cases we get a loop.
 		SvStringsSortDtor aSortOrigNames( 0, 128 );
 		SvStrings aOrigNames( 0, 128 );
diff --git a/main/svtools/source/filter/filter2.cxx b/main/svtools/source/filter/filter2.cxx
index 85116df..d291478 100644
--- a/main/svtools/source/filter/filter2.cxx
+++ b/main/svtools/source/filter/filter2.cxx
@@ -507,7 +507,7 @@ sal_Bool GraphicDescriptor::ImpDetectPCD( SvStream& rStm, sal_Bool )
 sal_Bool GraphicDescriptor::ImpDetectPCX( SvStream& rStm, sal_Bool bExtendedInfo )
 {
 	// ! Because 0x0a can be interpreted as LF too ...
-	// we cant be shure that this special sign represent a PCX file only.
+	// we can't be sure that this special sign represent a PCX file only.
 	// Every Ascii file is possible here :-(
 	// We must detect the whole header.
 	bExtendedInfo = sal_True;
diff --git a/main/unotools/source/config/configitem.cxx b/main/unotools/source/config/configitem.cxx
index eab1325..89d0b86 100644
--- a/main/unotools/source/config/configitem.cxx
+++ b/main/unotools/source/config/configitem.cxx
@@ -496,7 +496,7 @@ Sequence< sal_Bool > ConfigItem::GetReadOnlyStates(const com::sun::star::uno::Se
     sal_Int32 nCount = rNames.getLength();
     Sequence< sal_Bool > lStates(nCount);
 
-    // We must be shure to return a valid information every time!
+    // We must be sure to return a valid information every time!
     // Set default to non readonly ... similar to the configuration handling of this property.
     for ( i=0; i<nCount; ++i)
         lStates[i] = sal_False;
diff --git a/main/framework/qa/complex/framework/recovery/RecoveryTest.java b/main/framework/qa/complex/framework/recovery/RecoveryTest.java
index 28b9dc2..13b0348 100644
--- a/main/framework/qa/complex/framework/recovery/RecoveryTest.java
+++ b/main/framework/qa/complex/framework/recovery/RecoveryTest.java
@@ -171,7 +171,7 @@ public class RecoveryTest extends ComplexTestCase {
         msg +="-AppExecutionCommand=C:\\office\\soffice.exe -accept=socket,host=localhost,port=8101;urp;\n\n";
         msg +="Example UNIX:\n";
         msg +="-AppExecutionCommand=/office/soffice \"-accept=socket,host=localhost,port=8101;urp;\"\n\n";
-        msg+="NOTE: on UNIX be shure to have the connection string inside quotation mark!\n";
+        msg+="NOTE: on UNIX be sure to have the connection string inside quotation mark!\n";
 
         assure(msg, param.get("AppExecutionCommand") != null && ! param.get("AppExecutionCommand").equals(""));
         System.out.println("HALLO" + param.get("AppExecutionCommand"));
@@ -705,7 +705,7 @@ public class RecoveryTest extends ComplexTestCase {
         int height = rand.nextInt(maxHeight + 1);
         int width = rand.nextInt((windowMaxSize.Width-posSize.Y) + 1);
         
         // be shure that the new size his greater then the half of windowMaxSize
         posSize.Height = (height < (maxHeight / 2)) ? height + (maxHeight / 2) : height;
         posSize.Width =  (width < (maxWidth / 2)) ? width + (maxWidth / 2) : width;
         
@@ -705,7 +705,7 @@ public class RecoveryTest extends ComplexTestCase {
         int width = rand.nextInt((windowMaxSize.Width-posSize.Y) + 1);
         
-        // be shure that the new size his greater then the half of windowMaxSize
+        // be sure that the new size his greater then the half of windowMaxSize
         posSize.Height = (height < (maxHeight / 2)) ? height + (maxHeight / 2) : height;
         posSize.Width =  (width < (maxWidth / 2)) ? width + (maxWidth / 2) : width;
diff --git a/main/framework/source/inc/loadenv/actionlockguard.hxx b/main/framework/source/inc/loadenv/actionlockguard.hxx
index e48c439..283d61f 100644
--- a/main/framework/source/inc/loadenv/actionlockguard.hxx
+++ b/main/framework/source/inc/loadenv/actionlockguard.hxx
@@ -52,7 +52,7 @@ namespace css = ::com::sun::star;
 /** @short  implements a guard, which can use the interface
             <type scope="com::sun::star::document">XActionLockable</type>.
 
-    @descr  This guard should be used to be shure, that any lock will be
+    @descr  This guard should be used to be sure, that any lock will be
             released. Otherwhise the locaked document can hinder the office on shutdown!
 */
 class ActionLockGuard : private ThreadHelpBase
@@ -101,7 +101,7 @@ class ActionLockGuard : private ThreadHelpBase
         }
 
         //---------------------------------------
         /** @short  release this guard instance and make shure, that no lock
                     will exist afterwards on the internal wrapped resource.
          */
         virtual ~ActionLockGuard()
@@ -101,7 +101,7 @@ class ActionLockGuard : private ThreadHelpBase
 
         //---------------------------------------
-        /** @short  release this guard instance and make shure, that no lock
+        /** @short  release this guard instance and make sure, that no lock
                     will exist afterwards on the internal wrapped resource.
          */